/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/

package bb.io.filefilter;

import bb.io.DirUtil;

/**
* File filter that accepts files generated by a digital camera.
* <p>
* Specificly, this file filter accepts only normal files whose names end with the following extensions (case irrelevant):
* <ol>
*  <li><code>.avi</code></li>
*  <li><code>.jpeg</code></li>
*  <li><code>.jpg</code></li>
*  <li><code>.mov</code></li>
*  <li><code>.mp4</code></li>
*  <li><code>.thm</code></li>
* </ol>
* Directories and other file system elements are always rejected, which could affect directory drill down
* (see {@link DirUtil#getTree DirUtil.getTree} and {@link DirUtil#getFilesInTree DirUtil.getFilesInTree}).
* <p>
* For discussion of the .avi & .thm files produced by Canon digital cameras see
* <ol>
*  <li><a href="http://photography-on-the.net/forum/viewtopic.php?TopicID=6334">http://photography-on-the.net/forum/viewtopic.php?TopicID=6334</a></li>
*  <li><a href="http://www.extensis.com/portfolio/31j.html#raw11">http://www.extensis.com/portfolio/31j.html#raw11</a></li>
* </ol>
* Summary: .thm files are .jpg files (with some optional extra textual information too?) meant for thumbnails.
* <p>
* This class is multithread safe: it is immutable.
* In particular, it maintains its {@link SuffixFilter ancestor class}'s immutability.
* <p>
* @author Brent Boyer
*/
public class CameraFileFilter extends SuffixFilter {
	
	/** Constructs a new CameraFileFilter instance; directories are accepted. */
	public CameraFileFilter() {
		super(".avi", ".jpg", ".jpeg", ".mov", ".mp4", ".thm");
	}
	
	@Override public String getDescription() { return "Digital Camera Files"; }
	
}
